@@ -5,7 +5,7 @@ with open("README.md", "r", encoding="utf-8") as fh:
 
 setuptools.setup(
     name="arcframework",  # Replace with your own username
-    version="1.3.1",
+    version="1.3.2",
     author="Rayyan Cyclegar",
     author_email="aboominister@gmail.com",
     description="A Python micro web framework for creating dynamic websites.",
@@ -24,6 +24,6 @@ setuptools.setup(
     ],
     include_package_data=True,
     package_data={
-        "arc": ["selfpages/*.html"]
+        "arc": ["selfpages/*.html", "static/*.css"],
     }
 )
